import React from "react";
import { Accordion } from "@fchh/fcos-suite-ui";
import { useEffect } from "react";
import Icon from "./Icon";

type LabsAccordionWrapperProps = {
  title: string;
  id?: string;
  icon?: string;
  className?: string;
  contentHtml?: string;
  open?: boolean;
};

const LabsAccordionWrapper: React.FC<LabsAccordionWrapperProps> = ({
  title,
  id,
  icon,
  contentHtml,
  open,
  ...restProps
}) => {
  useEffect(() => {
    const details = document.querySelectorAll(`details#${id}`);
    details.forEach((targetDetail) => {
      targetDetail.addEventListener("click", () => {
        details.forEach((detail) => {
          if (detail !== targetDetail) {
            detail.removeAttribute("open");
          }
        });
      });
    });
  }, []);
  const [leftColumn, rightColumn] = contentHtml.split("<hr/>");
  return (
    <Accordion
      title={title}
      id={id}
      open={open}
      {...restProps}
      {...(icon ? { icon: <Icon name={icon} className="w-6 h-6" /> } : {})}
    >
      <div
        className={`${rightColumn ? "fc-grid fc-grid-cols-2 fc-gap-x-2" : ""}`}
      >
        <div dangerouslySetInnerHTML={{ __html: leftColumn }} />
        {rightColumn && (
          <div dangerouslySetInnerHTML={{ __html: rightColumn }} />
        )}
      </div>
    </Accordion>
  );
};

export default LabsAccordionWrapper;
